==> openshift-model-monitoring-4.11.1-sources.jar: annotations/io/fabric8/openshift/api/model/monitoring/v1/PodMonitorFluent.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.StringBuffer;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface PodMonitorFluent<A extends PodMonitorFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata();
    public ObjectMeta buildMetadata();
    public A withMetadata(ObjectMeta metadata);
    public Boolean hasMetadata();
    public PodMonitorFluent.MetadataNested<A> withNewMetadata();
    public PodMonitorFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
    public PodMonitorFluent.MetadataNested<A> editMetadata();
    public PodMonitorFluent.MetadataNested<A> editOrNewMetadata();
    public PodMonitorFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public PodMonitorSpec getSpec();
    public PodMonitorSpec buildSpec();
    public A withSpec(PodMonitorSpec spec);
    public Boolean hasSpec();
    public PodMonitorFluent.SpecNested<A> withNewSpec();
    public PodMonitorFluent.SpecNested<A> withNewSpecLike(PodMonitorSpec item);
    public PodMonitorFluent.SpecNested<A> editSpec();
    public PodMonitorFluent.SpecNested<A> editOrNewSpec();
    public PodMonitorFluent.SpecNested<A> editOrNewSpecLike(PodMonitorSpec item);

    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectMetaFluent<PodMonitorFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}
    public interface SpecNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,PodMonitorSpecFluent<PodMonitorFluent.SpecNested<N>>{

        
    public N and();    public N endSpec();
}


}

==> openshift-model-monitoring-5.3.0-sources.jar: annotations/io/fabric8/openshift/api/model/monitoring/v1/PodMonitorFluent.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.StringBuffer;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface PodMonitorFluent<A extends PodMonitorFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(int[] arg1,int arg2,int arg3);
    public A withNewApiVersion(char[] arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A withNewApiVersion(byte[] arg1,int arg2);
    public A withNewApiVersion(byte[] arg1);
    public A withNewApiVersion(char[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewApiVersion(String arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(int[] arg1,int arg2,int arg3);
    public A withNewKind(char[] arg1);
    public A withNewKind(StringBuffer arg1);
    public A withNewKind(byte[] arg1,int arg2);
    public A withNewKind(byte[] arg1);
    public A withNewKind(char[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewKind(String arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata();
    public ObjectMeta buildMetadata();
    public A withMetadata(ObjectMeta metadata);
    public Boolean hasMetadata();
    public PodMonitorFluent.MetadataNested<A> withNewMetadata();
    public PodMonitorFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
    public PodMonitorFluent.MetadataNested<A> editMetadata();
    public PodMonitorFluent.MetadataNested<A> editOrNewMetadata();
    public PodMonitorFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public PodMonitorSpec getSpec();
    public PodMonitorSpec buildSpec();
    public A withSpec(PodMonitorSpec spec);
    public Boolean hasSpec();
    public PodMonitorFluent.SpecNested<A> withNewSpec();
    public PodMonitorFluent.SpecNested<A> withNewSpecLike(PodMonitorSpec item);
    public PodMonitorFluent.SpecNested<A> editSpec();
    public PodMonitorFluent.SpecNested<A> editOrNewSpec();
    public PodMonitorFluent.SpecNested<A> editOrNewSpecLike(PodMonitorSpec item);
    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectMetaFluent<PodMonitorFluent.MetadataNested<N>> {

            public N and();
            public N endMetadata();    }


    public interface SpecNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,PodMonitorSpecFluent<PodMonitorFluent.SpecNested<N>> {

            public N and();
            public N endSpec();    }


}
